@@ -20,8 +20,8 @@
 #ifndef BIBTEXFILEEXPORTEREXTERNAL_H
 #define BIBTEXFILEEXPORTEREXTERNAL_H
 
-#include <fileexporter.h>
-#include <settings.h>
+#include "fileexporter.h"
+#include "settings.h"
 
 class TQWaitCondition;
 class TQProcess;
